Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(454)

Unified Diff: components/payments/core/address_normalizer_impl_unittest.cc

Issue 2829903004: Reland: Normalize shipping address for merchant on Desktop. (Closed)
Patch Set: Make android code use the new impl Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/payments/core/address_normalizer_impl_unittest.cc
diff --git a/components/payments/core/address_normalizer_unittest.cc b/components/payments/core/address_normalizer_impl_unittest.cc
similarity index 95%
rename from components/payments/core/address_normalizer_unittest.cc
rename to components/payments/core/address_normalizer_impl_unittest.cc
index da9760b3ef28e450083520abd7a64560587193c0..495dd04030c8739d000c1f313529e44639a5c423 100644
--- a/components/payments/core/address_normalizer_unittest.cc
+++ b/components/payments/core/address_normalizer_impl_unittest.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "components/payments/core/address_normalizer.h"
+#include "components/payments/core/address_normalizer_impl.h"
#include <utility>
@@ -79,13 +79,13 @@ class ChromiumTestdataSource : public TestdataSource {
DISALLOW_COPY_AND_ASSIGN(ChromiumTestdataSource);
};
-// A test subclass of the AddressNormalizer. Used to simulate rules not being
-// loaded.
-class TestAddressNormalizer : public AddressNormalizer {
+// A test subclass of the AddressNormalizerImpl. Used to simulate rules not
+// being loaded.
+class TestAddressNormalizer : public AddressNormalizerImpl {
public:
TestAddressNormalizer(std::unique_ptr<::i18n::addressinput::Source> source,
std::unique_ptr<::i18n::addressinput::Storage> storage)
- : AddressNormalizer(std::move(source), std::move(storage)),
+ : AddressNormalizerImpl(std::move(source), std::move(storage)),
should_load_rules_(true) {}
~TestAddressNormalizer() override {}
@@ -96,7 +96,7 @@ class TestAddressNormalizer : public AddressNormalizer {
void LoadRulesForRegion(const std::string& region_code) override {
if (should_load_rules_) {
- AddressNormalizer::LoadRulesForRegion(region_code);
+ AddressNormalizerImpl::LoadRulesForRegion(region_code);
}
}
« no previous file with comments | « components/payments/core/address_normalizer_impl.cc ('k') | components/payments/core/address_normalizer_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698